#!/usr/bin/env python3

import sys
from sklearn import datasets
import numpy as np
from sklearn.model_selection import train_test_split
from sklearn.preprocessing import StandardScaler
from sklearn.linear_model import Perceptron
from sklearn.metrics import accuracy_score

if len(sys.argv) == 1:
    TESTSIZE = 0.3
else:
    TESTSIZE = float(sys.argv[1])

print('Test Size:', TESTSIZE)

iris = datasets.load_iris()
X = iris.data[:, [2, 3]]
y = iris.target

print('Labels:', np.unique(y))
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=TESTSIZE, random_state=1, stratify=y)
sc = StandardScaler()
sc.fit(X_train)
X_train_std = sc.transform(X_train)
X_test_std = sc.transform(X_test)

ppn = Perceptron(max_iter=40, eta0=0.1, random_state=1)
ppn.fit(X_train_std, y_train)

y_pred = ppn.predict(X_test_std)
print('Misclassified samples: %d' % (y_test != y_pred).sum())

print('Accuracy: %.2f' % accuracy_score(y_test, y_pred))
print('Accuracy: %.2f' % ppn.score(X_test_std, y_test))

