#!/usr/bin/python
##########
#
# Name: ACswitch_control.py
# Description:measure tempature from DHT22 senors in GPIO11
# Version 1.0
# Date: Oct. 15, 2017
#
#########

import sys					#provides access to some variables used or maintained by the interpreter
import os					#provides a portable way of using operating system dependent functionality.
import datetime				#provides classes for manipulating dates and times
import time					#provides various time-related functions
import RPi.GPIO as GPIO		#provides interface to input/output pins of the Pi
import Adafruit_DHT			#provides the ability to read the DHT series of sensors from a Raspberry Pi

#setup
GPIO.setmode(GPIO.BOARD)	#set option to reference physical pins
TriacPin = 23				#Broadcom GPIO 11 (pin 23)
GPIO.setup(TriacPin, GPIO.OUT) # declare pin to be an output

#variable definition
trip_temp = -15				#triac on temperature
lower_time_limit = 3		#triac on earliest time
upper_time_limit = 8		#triac on latest time
logic_override = 0			#triac on because users wants it to be on
now = datetime.datetime.now()	#what is time right now


try:

	while 1:
		humidity, temperature = Adafruit_DHT.read_retry(Adafruit_DHT.AM2302,14)	#GPIO 14 found on pin 8

		time.sleep(3)

		if humidity is not None and temperature is not None:
			print('Temp = {0:0.1f}'.format(temperature))
		else:
    			print('Failed to get reading. Try again!')
			temperature = 0	# set a value so there is variable to support the code.

		if temperature <= trip_temp and now.hour >= lower_time_limit and now.hour <= upper_time_limit:
			print("HIGH on logic")
			GPIO.output(TriacPin,GPIO.HIGH) #triac on, temp is below -15 and it is between 3am & 8am
		elif logic_override == 1:
			print("High on override")
			GPIO.output(TriacPin,GPIO.HIGH) #triac on, user override
		else:
			print("LOW on logic")
			GPIO.output(TriacPin,GPIO.LOW) #triac off, temp is above -15 or it is not between 3am & 8am

except KeyboardInterrupt: #if ctrl+c pressed exit cleanly
	GPIO.cleanup()
except: # this catches ALL other exceptions including errors.
	GPIO.cleanup()
finally: #cleanup GPIO on normal exit
	GPIO.cleanup()
